@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -14,7 +14,7 @@ std::string StrCat(span<const StringPiece> pieces) {
   return internal::StrCatT(pieces);
 }
 
-string16 StrCat(span<const StringPiece16> pieces) {
+std::u16string StrCat(span<const StringPiece16> pieces) {
   return internal::StrCatT(pieces);
 }
 
@@ -22,7 +22,7 @@ std::string StrCat(span<const std::string> pieces) {
   return internal::StrCatT(pieces);
 }
 
-string16 StrCat(span<const string16> pieces) {
+std::u16string StrCat(span<const std::u16string> pieces) {
   return internal::StrCatT(pieces);
 }
 
@@ -30,7 +30,7 @@ void StrAppend(std::string* dest, span<const StringPiece> pieces) {
   internal::StrAppendT(*dest, pieces);
 }
 
-void StrAppend(string16* dest, span<const StringPiece16> pieces) {
+void StrAppend(std::u16string* dest, span<const StringPiece16> pieces) {
   internal::StrAppendT(*dest, pieces);
 }
 
@@ -38,7 +38,7 @@ void StrAppend(std::string* dest, span<const std::string> pieces) {
   internal::StrAppendT(*dest, pieces);
 }
 
-void StrAppend(string16* dest, span<const string16> pieces) {
+void StrAppend(std::u16string* dest, span<const std::u16string> pieces) {
   internal::StrAppendT(*dest, pieces);
 }
 
